<?php
/*
Plugin Name: trigami nofollow
Plugin URI: http://www.awokenmind.de/2007-12-01/trigami-nofollow
Description: Searches for links to trigami.com and adds a rel="nofollow" tag. If a trigami-link was found in a post EVERY following link in this post will be equipped with a rel="nofollow" tag.
Author: Andreas Brett (based on 'Wikipedia nofollow' by Key Yasumoto-Nicolson and 'Identify External Links' by Mark Jaquith)
Version: 1.0
Author URI: http://www.awokenmind.de
*/

/* Based on:
Plugin Name: Wikipedia nofollow
Plugin URI: http://whatjapanthinks.com/wikipedia-nofollow/
Description: Searches for links to Wikipedia.org, and adds a rel="nofollow" tag if necessary
Author: Ken Yasumoto-Nicolson (based on Identify External Links by Mark Jaquith)
Version: 1.0
Author URI: http://whatjapanthinks.com
*/

/* Based on:
Plugin Name: Identify External Links
Plugin URI: http://txfx.net/code/wordpress/identify-external-links/
Description: Searches the text for links outside of the domain of the blog.	 To these, it adds <strong>class="extlink"</strong> (and optionally, <strong>target="_blank"</strong>).
Author: Mark Jaquith
Version: 1.3
Author URI: http://txfx.net/
*/

/*	Copyright 2005	Mark Jaquith (email: mark.gpl@txfx.net)
   Additional changes Copyright 2007 Ken Yasumoto-Nicolson (email: seron@whatjapanthinks.com)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


// change this to true if you want external links to open in a new window (target="_blank")
$txfx_iel_use_target_blank = false;

function wp_get_domain_name_from_uri($uri){
	preg_match("/^(http:\/\/)?([^\/]+)/i", $uri, $matches);
	$host = $matches[2];
	preg_match("/[^\.\/]+\.[^\.\/]+$/", $host, $matches);
	return $matches[0];	   
}

function wp_has_no_rel_nofollow($text)
{
	if ( preg_match("/rel=[\"\'].*?nofollow.*?[\"\']/i", $text ) )
		return false;
	else
		return true;
}

function parse_trigami_nofollow($matches)
{
	global $isTrigamiPost;
	
	// trigamiPost detected => every link will be nofollow-equipped
	if ($isTrigamiPost == true) {
		return '<a rel="nofollow" href="' . $matches[2] . '//' . $matches[3] . '"' . $matches[1] . $matches[4] . '>' . $matches[5] . '</a>';
	}
	
	if ( wp_get_domain_name_from_uri($matches[3]) == "trigami.com" &&
		  wp_has_no_rel_nofollow( $matches[1] ) &&
		  wp_has_no_rel_nofollow( $matches[4] ) )
	{
		$isTrigamiPost = true;
		return '<a rel="nofollow" href="' . $matches[2] . '//' . $matches[3] . '"' . $matches[1] . $matches[4] . '>' . $matches[5] . '</a>';
	}
	else
	{
		// Do nothing
		return '<a href="' . $matches[2] . '//' . $matches[3] . '"' . $matches[1] . $matches[4] . '>' . $matches[5] . '</a>';
	}
}
	

function wp_trigami_nofollow($text) 
{
	$pattern = '/<a (.*?)href=[\"\'](.*?)\/\/(.*?)[\"\'](.*?)>(.*?)<\/a>/i';
	$text = preg_replace_callback($pattern,'parse_trigami_nofollow',$text);
	return $text;
}

$isTrigamiPost = false;

// filters have high priority to make sure that any markup plugins like Textile or Markdown have already created the HTML links
add_filter('the_content', 'wp_trigami_nofollow', 999);
add_filter('the_excerpt', 'wp_trigami_nofollow', 999);
?>